@@ -31,6 +31,7 @@ console = Console()
 @app.command("stage")
 @beartype
 def stage(
+    # Advanced/Configuration
     preset: str = typer.Option(
         "balanced",
         "--preset",
@@ -45,8 +46,13 @@ def stage(
     - balanced: Block HIGH severity, warn MEDIUM
     - strict:   Block all MEDIUM+ violations
 
-    Example:
+    **Parameter Groups:**
+    - **Advanced/Configuration**: --preset
+
+    **Examples:**
         specfact enforce stage --preset balanced
+        specfact enforce stage --preset strict
+        specfact enforce stage --preset minimal
     """
     telemetry_metadata = {
         "preset": preset.lower(),
@@ -113,28 +119,31 @@ def stage(
 @require(lambda out: out is None or isinstance(out, Path), "Out must be None or Path")
 def enforce_sdd(
     # Target/Input
-    bundle: str = typer.Argument(..., help="Project bundle name (e.g., legacy-api, auth-module)"),
+    bundle: str | None = typer.Argument(
+        None,
+        help="Project bundle name (e.g., legacy-api, auth-module). Default: active plan from 'specfact plan select'",
+    ),
     sdd: Path | None = typer.Option(
         None,
         "--sdd",
-        help="Path to SDD manifest (default: .specfact/sdd/<bundle-name>.<format>)",
+        help="Path to SDD manifest. Default: .specfact/sdd/<bundle-name>.<format>",
     ),
     # Output/Results
     output_format: str = typer.Option(
         "yaml",
         "--output-format",
-        help="Output format (yaml, json, markdown)",
+        help="Output format (yaml, json, markdown). Default: yaml",
     ),
     out: Path | None = typer.Option(
         None,
         "--out",
-        help="Output file path (default: .specfact/reports/sdd/validation-<timestamp>.<format>)",
+        help="Output file path. Default: .specfact/reports/sdd/validation-<timestamp>.<format>",
     ),
     # Behavior/Options
     no_interactive: bool = typer.Option(
         False,
         "--no-interactive",
-        help="Non-interactive mode (for CI/CD automation)",
+        help="Non-interactive mode (for CI/CD automation). Default: False (interactive mode)",
     ),
 ) -> None:
     """
@@ -146,15 +155,35 @@ def enforce_sdd(
     - Frozen sections (hash mismatch detection)
     - Contract density metrics
 
-    Example:
+    **Parameter Groups:**
+    - **Target/Input**: bundle (required argument), --sdd
+    - **Output/Results**: --output-format, --out
+    - **Behavior/Options**: --no-interactive
+
+    **Examples:**
         specfact enforce sdd legacy-api
         specfact enforce sdd auth-module --output-format json --out validation-report.json
+        specfact enforce sdd legacy-api --no-interactive
     """
+    from rich.console import Console
+
     from specfact_cli.models.sdd import SDDManifest
     from specfact_cli.utils.bundle_loader import load_project_bundle
     from specfact_cli.utils.structure import SpecFactStructure
+    from specfact_cli.utils.structured_io import StructuredFormat
+
+    console = Console()
+
+    # Use active plan as default if bundle not provided
+    if bundle is None:
+        bundle = SpecFactStructure.get_active_bundle_name(Path("."))
+        if bundle is None:
+            console.print("[bold red]✗[/bold red] Bundle name required")
+            console.print("[yellow]→[/yellow] Use --bundle option or run 'specfact plan select' to set active plan")
+            raise typer.Exit(1)
+        console.print(f"[dim]Using active plan: {bundle}[/dim]")
+
     from specfact_cli.utils.structured_io import (
-        StructuredFormat,
         dump_structured_file,
         load_structured_file,
     )
@@ -175,26 +204,21 @@ def enforce_sdd(
             console.print(f"[dim]Create one with: specfact plan init {bundle}[/dim]")
             raise typer.Exit(1)
 
-        # Find SDD manifest path (one per bundle: .specfact/sdd/<bundle-name>.yaml)
-        if sdd is None:
-            base_path = Path(".")
-            # Try YAML first, then JSON
-            sdd_yaml = base_path / SpecFactStructure.SDD / f"{bundle}.yaml"
-            sdd_json = base_path / SpecFactStructure.SDD / f"{bundle}.json"
-            if sdd_yaml.exists():
-                sdd = sdd_yaml
-            elif sdd_json.exists():
-                sdd = sdd_json
-            else:
-                console.print("[bold red]✗[/bold red] SDD manifest not found")
-                console.print(f"[dim]Expected: {sdd_yaml} or {sdd_json}[/dim]")
-                console.print(f"[dim]Create one with: specfact plan harden {bundle}[/dim]")
-                raise typer.Exit(1)
+        # Find SDD manifest path using discovery utility
+        from specfact_cli.utils.sdd_discovery import find_sdd_for_bundle
 
-        if not sdd.exists():
-            console.print(f"[bold red]✗[/bold red] SDD manifest not found: {sdd}")
+        base_path = Path(".")
+        discovered_sdd = find_sdd_for_bundle(bundle, base_path, sdd)
+        if discovered_sdd is None:
+            console.print("[bold red]✗[/bold red] SDD manifest not found")
+            console.print(f"[dim]Searched for: .specfact/sdd/{bundle}.yaml or .specfact/sdd/{bundle}.json[/dim]")
+            console.print("[dim]Legacy fallback: .specfact/sdd.yaml or .specfact/sdd.json[/dim]")
+            console.print(f"[dim]Create one with: specfact plan harden {bundle}[/dim]")
             raise typer.Exit(1)
 
+        sdd = discovered_sdd
+        console.print(f"[dim]Using SDD manifest: {sdd}[/dim]")
+
         try:
             # Load SDD manifest
             console.print(f"[dim]Loading SDD manifest: {sdd}[/dim]")
@@ -303,6 +327,55 @@ def enforce_sdd(
                 console.print(f"[dim]Frozen sections: {len(sdd_manifest.frozen_sections)}[/dim]")
                 # TODO: Implement hash-based frozen section validation in Phase 6
 
+            # 4. Validate OpenAPI/AsyncAPI specs with Specmatic (if found)
+            console.print("\n[cyan]Validating API specifications...[/cyan]")
+            import asyncio
+
+            from specfact_cli.integrations.specmatic import check_specmatic_available, validate_spec_with_specmatic
+
+            base_path = Path(".")
+            spec_files = []
+            for pattern in [
+                "**/openapi.yaml",
+                "**/openapi.yml",
+                "**/openapi.json",
+                "**/asyncapi.yaml",
+                "**/asyncapi.yml",
+                "**/asyncapi.json",
+            ]:
+                spec_files.extend(base_path.glob(pattern))
+
+            if spec_files:
+                console.print(f"[dim]Found {len(spec_files)} API specification file(s)[/dim]")
+                is_available, error_msg = check_specmatic_available()
+                if is_available:
+                    for spec_file in spec_files[:5]:  # Validate up to 5 specs
+                        console.print(f"[dim]Validating {spec_file.relative_to(base_path)} with Specmatic...[/dim]")
+                        try:
+                            result = asyncio.run(validate_spec_with_specmatic(spec_file))
+                            if not result.is_valid:
+                                deviation = Deviation(
+                                    type=DeviationType.CONTRACT_VIOLATION,
+                                    severity=DeviationSeverity.MEDIUM,
+                                    description=f"API specification validation failed: {spec_file.name}",
+                                    location=str(spec_file),
+                                    fix_hint=f"Run 'specfact spec validate {spec_file}' to see detailed errors",
+                                )
+                                report.add_deviation(deviation)
+                                console.print(f"  [bold yellow]⚠[/bold yellow] {spec_file.name} has validation issues")
+                            else:
+                                console.print(f"  [bold green]✓[/bold green] {spec_file.name} is valid")
+                        except Exception as e:
+                            console.print(f"  [bold yellow]⚠[/bold yellow] Validation error: {e!s}")
+                    if len(spec_files) > 5:
+                        console.print(
+                            f"[dim]... and {len(spec_files) - 5} more spec file(s) (run 'specfact spec validate' to validate all)[/dim]"
+                        )
+                else:
+                    console.print(f"[dim]💡 Tip: Install Specmatic to validate API specs: {error_msg}[/dim]")
+            else:
+                console.print("[dim]No API specification files found[/dim]")
+
             # Generate output report
             output_format_str = output_format.lower()
             if out is None:
